@@ -18,9 +18,8 @@ import base64
 from typing import List, Tuple, Optional, Union, Type
 from collections import OrderedDict
 import sys
-sys.path.append("..")
-from custom_exceptions.salesforce_exceptions import *
-from utilities.df_utils import *
+from salesforce.custom_exceptions.salesforce_exceptions import *
+from salesforce.utilities.df_utils import *
 from salesforce.decorators import *
 
 
